summaryrefslogtreecommitdiffstats
path: root/test/genall5.c
diff options
context:
space:
mode:
authorSongyu Lu <songyulu@hdfgroup.org>2021-04-05 16:29:15 (GMT)
committerSongyu Lu <songyulu@hdfgroup.org>2021-04-05 16:29:15 (GMT)
commitda80917711737e600fceda8f1068f0b35f2eda25 (patch)
tree4fa2a8c59c7ecf90a76dd830ad3f81e768d03b94 /test/genall5.c
parent209a194993925166dd70815059e437074a3c2be4 (diff)
downloadhdf5-da80917711737e600fceda8f1068f0b35f2eda25.zip
hdf5-da80917711737e600fceda8f1068f0b35f2eda25.tar.gz
hdf5-da80917711737e600fceda8f1068f0b35f2eda25.tar.bz2
Two main changes include: re-arranging the communication between the writer and reader through the named pipes; using the error report consistent with other tests.
Diffstat (limited to 'test/genall5.c')
-rw-r--r--test/genall5.c6
1 files changed, 4 insertions, 2 deletions
diff --git a/test/genall5.c b/test/genall5.c
index 2cb7b9e..016b368 100644
--- a/test/genall5.c
+++ b/test/genall5.c
@@ -19,6 +19,7 @@
* of the same name.
*/
+#include <err.h>
#include "cache_common.h"
#include "vfd_swmr_common.h" /* for below_speed_limit() */
#include "genall5.h"
@@ -2754,8 +2755,9 @@ tend_zoo(hid_t fid, const char *base_path, struct timespec *lastmsgtime, zoo_con
out:
if (!ok) {
/* Only the zoo test for VFD SWMR does this step, making sure it doesn't take too long.
- * Other tests sets config.msgival to 0 and will skip this step */
- if (strcmp(failure_mssg, last_failure_mssg) != 0 && ((config.msgival.tv_sec || config.msgival.tv_nsec))) {
+ * Other tests sets config.msgival or lastmsgtime to 0 and will skip this step */
+ if (strcmp(failure_mssg, last_failure_mssg) != 0 && ((config.msgival.tv_sec || config.msgival.tv_nsec))
+ && (lastmsgtime->tv_sec || lastmsgtime->tv_nsec)) {
if (below_speed_limit(lastmsgtime, &config.msgival)) {
last_failure_mssg = failure_mssg;
warnx("%s: %s", __func__, failure_mssg);